<?php
/***********************************************************
*  Module       : Import
*  Language     : ES Spanish
*  Version      : vt5.0.4
*  Created Date : 2008-01-18 17:46:07 Last change : 2008-01-18 18:28:41
*  Author       : JPL TSolucio, S.L.  -  rasomu
*  License      : 

***********************************************************/


$mod_strings = array (
      'LBL_IMPORT_MODULE_NO_DIRECTORY' => 'El directorio ',
      'LBL_IMPORT_MODULE_NO_DIRECTORY_END' => ' no existe o no es posible escribir en él',
      'LBL_IMPORT_MODULE_ERROR_NO_UPLOAD' => 'El archivo no fue procesado con exito, inténtelo de nuevo',
      'LBL_IMPORT_MODULE_ERROR_LARGE_FILE' => 'El archivo es muy grande, máximo:',
      'LBL_IMPORT_MODULE_ERROR_LARGE_FILE_END' => 'Bytes. Modifique $upload_maxsize en config.php',
      'LBL_MODULE_NAME' => 'Importar',
      'LBL_TRY_AGAIN' => 'Intentar de Nuevo',
      'LBL_ERROR' => 'Error:',
      'ERR_MULTIPLE' => 'Múltiples columnas han sido definidas con el mismo campo.',
      'ERR_MISSING_REQUIRED_FIELDS' => 'Campos requeridos que faltan:',
      'ERR_SELECT_FULL_NAME' => 'No puede seleccionar nombre completo cuando nombre y apellido son seleccionados.',
      'ERR_SELECT_FILE' => 'Seleccionar un archivo a procesar.',
      'LBL_SELECT_FILE' => 'Seleccionar Archivo:',
      'LBL_CUSTOM' => 'Personalizar',
      'LBL_DONT_MAP' => '-- Sin Asignar --',
      'LBL_STEP_1_TITLE' => 'Seleccione el archivo CSV',
      'LBL_WHAT_IS' => 'Por favor, seleccione entre los siguiente un origen de datos:',
      'LBL_MICROSOFT_OUTLOOK' => 'Microsoft Outlook',
      'LBL_ACT' => 'Act!',
      'LBL_SALESFORCE' => 'Salesforce.com',
      'LBL_MY_SAVED' => 'Mis origenes guardados:',
      'LBL_PUBLISH' => 'publicar',
      'LBL_DELETE' => 'eliminar',
      'LBL_PUBLISHED_SOURCES' => 'Origenes publicados:',
      'LBL_UNPUBLISH' => 'No publicar',
      'LBL_NEXT' => 'Siguiente',
      'LBL_BACK' => 'Atras',
      'LBL_STEP_2_TITLE' => 'Paso 2 de 4: Procesar archivo de exportación',
      'LBL_HAS_HEADER' => 'Tiene Cabecera:',
      'LBL_NUM_1' => '1.',
      'LBL_NUM_2' => '2.',
      'LBL_NUM_3' => '3.',
      'LBL_NUM_4' => '4.',
      'LBL_NUM_5' => '5.',
      'LBL_NUM_6' => '6.',
      'LBL_NUM_7' => '7.',
      'LBL_NUM_8' => '8.',
      'LBL_NUM_9' => '9.',
      'LBL_NUM_10' => '10.',
      'LBL_NUM_11' => '11.',
      'LBL_NUM_12' => '12.',
      'LBL_NOW_CHOOSE' => 'Ahora seleccione el archivo a importar:',
      'LBL_IMPORT_OUTLOOK_TITLE' => 'Microsoft Outlook 98 y 2000 pueden exportar datos en formato <b>Comma Separated Values</b> el cual puede ser utilizado para importar datos al sistema. Para exportar datos de Outlook, siga los siguientes pasos:',
      'LBL_OUTLOOK_NUM_1' => 'Iniciar <b>Outlook</b>',
      'LBL_OUTLOOK_NUM_2' => 'Seleccione el menú <b>File</b>, luego la opción de menú <b>Import and Export ...</b> ',
      'LBL_OUTLOOK_NUM_3' => 'Elija <b>Export a un file</b> y seleccione Next',
      'LBL_OUTLOOK_NUM_4' => 'Elija <b>Comma Separated Values (Windows)</b> y seleccione <b>Next</b>.<br>  Nota: Puede ser requerido que instale el componente Importar/Exportar',
      'LBL_OUTLOOK_NUM_5' => 'Seleccione la carpeta <b>Contacts</b> y haga click en <b>Next</b>. Usted puede seleccionar diferentes carpetas de contactos  si los tiene distribuidos en mas de una',
      'LBL_OUTLOOK_NUM_6' => 'Elija un nombre de archivo y haga click en <b>Next</b>',
      'LBL_OUTLOOK_NUM_7' => 'Haga click en <b>Finish</b>',
      'LBL_IMPORT_ACT_TITLE' => 'Act! Ya puede exportar datos en formato <b>Comma Separated Values</b> el cual puede ser utilizado para importar datos al sistema. Para exportar datos de Act!, siga los siguientes pasos:',
      'LBL_ACT_NUM_1' => 'Inicie <b>ACT!</b>',
      'LBL_ACT_NUM_2' => 'Seleccione en el menu <b>File</b> , la opción <b>Data Exchange</b> , luego la opción <b>Export...</b> ',
      'LBL_ACT_NUM_3' => 'Seleccione el tipo de archivo <b>Text-Delimited</b>',
      'LBL_ACT_NUM_4' => 'Elija un nombre de archivo y ubicación del mismo y luego haga click en  <b>Next</b>',
      'LBL_ACT_NUM_5' => 'Seleccione unicamente <b>Contacts records only</b>',
      'LBL_ACT_NUM_6' => 'Haga click en el boton <b>Options...</b> ',
      'LBL_ACT_NUM_7' => 'Seleccione <b>Comma</b> como caracter de separación',
      'LBL_ACT_NUM_8' => 'Marque la casilla <b>Yes, export field names</b> y haga click en <b>OK</b>',
      'LBL_ACT_NUM_9' => 'haga click en  <b>Next</b>',
      'LBL_ACT_NUM_10' => 'Seleccione <b>All Records</b> y luego haga click en <b>Finish</b>',
      'LBL_IMPORT_SF_TITLE' => 'Salesforce.com puede exportar datos en formato <b>Comma Separated Values</b> que puede ser utilizado para importar datos en el sistema. Para exportar datos de Salesforce.com, siga los siguientes pasos:',
      'LBL_SF_NUM_1' => 'Abra su navegador en http://www.salesforce.com, y acceda al sistema con su usuario y contraseña',
      'LBL_SF_NUM_2' => 'Haga click en el Tab <b>Reports</b> del menu superior ',
      'LBL_SF_NUM_3' => 'Para exportar cuentas:</b> haga click en <b>Active Accounts</b> link<br><b> Para Exportar contactos:</b> Click en <b>Mailing List</b> ',
      'LBL_SF_NUM_4' => 'En el <b>Paso 1: Seleccione el tipo de informe</b>, seleccione <b>Tabular informe</b>click <b>Next</b>',
      'LBL_SF_NUM_5' => 'En el <b>Paso 2: Seleccione las columnas del informe</b>, Elija las columnas que desea exportar y haga click en <b>Next</b>',
      'LBL_SF_NUM_6' => 'En el <b>Paso 3: Seleccione la información a incluir resumen</b>, haga click<b>Next</b>',
      'LBL_SF_NUM_7' => 'En el <b>Paso 4: Ordene las columnas del informe</b>, haga click en <b>Next</b>',
      'LBL_SF_NUM_8' => 'En el <b>Paso 5: Seleccione el criterio del informe</b>, en <b>Start Date</b>, elija la fecha de inicio. Tambien puede exportar cuentas específicas utilizando criterios mas avanzados. Cuando haya finalizados, haga click en <b>Run Report</b>',
      'LBL_SF_NUM_9' => 'Un informe será generado y la página debera deberá mostrar <b>Report Generation Status: Complete.</b> Now click <b>Exportar a Excel</b>',
      'LBL_SF_NUM_10' => 'En <b>Export Report:</b>, para <b>Export File Format:</b>, elija <b>Comma Delimited .csv</b>. Haga click en <b>Export</b>.',
      'LBL_SF_NUM_11' => 'Se abrira un diálogo para guardar el archivo en su equipo.',
      'LBL_IMPORT_CUSTOM_TITLE' => 'Múltiples aplicaciones le permiten exportar datos en formato <b>Comma Delimited text file (.csv)</b>. Generalmente, la mayoría de ellas siguen estos pasos generales:',
      'LBL_CUSTOM_NUM_1' => 'Ejecute la aplicación y abra el archivo de datos',
      'LBL_CUSTOM_NUM_2' => 'Seleccione la opcion <b>Save As...</b> o <b>Export...</b> del menu',
      'LBL_CUSTOM_NUM_3' => 'Guarde el archivo en formato <b>CSV</b> o <b>Comma Separated Values</b> ',
      'LBL_STEP_3_TITLE' => 'Paso 3 de 4: Confirmar campos e importar',
      'LBL_STEP_1' => 'Paso 1 de 3: ',
      'LBL_STEP_1_TEXT' => ' vtiger CRM soporta importar registros desde archivos .csv (<b>Separados por Comas</b>). Para empezar la importación, localice el archivo CSV y pulse en el botón Siguiente para Continuar.',
      'LBL_SELECT_FIELDS_TO_MAP' => 'En la siguiente lista seleccione los campos a importar desde el archivo que deben ser incluidos en cada campo del sistema. Cuando haya finalizado, haga click en <b>Import Now</b>',
      'LBL_DATABASE_FIELD' => 'Campo de la Base',
      'LBL_HEADER_ROW' => 'Fila de cabecera',
      'LBL_ROW' => 'Fila',
      'LBL_SAVE_AS_CUSTOM' => 'Salvar como asignación personalizada:',
      'LBL_CONTACTS_NOTE_1' => 'Apellido o nombre completo deben asignarse.',
      'LBL_CONTACTS_NOTE_2' => 'Si asigna "nombre completo", "nombre" y "apellido" seran ignorados.',
      'LBL_CONTACTS_NOTE_3' => 'Si asigna "nombre completo", los datos se distribuirán en "Nombre" y "Apellidos" una vez insertada la información en la base de datos.',
      'LBL_CONTACTS_NOTE_4' => 'Los Campos terminados en Dirección 2 y Dirección 3 son concatenados juntos en el campo "Dirección principal" al insertarse en la base de datos.',
      'LBL_ACCOUNTS_NOTE_1' => 'El nombre de cuanta debe asignarse.',
      'LBL_ACCOUNTS_NOTE_2' => 'Campos terminados en Dirección 2 y Dirección 3 se concatenan en el campo "Dirección principal" al ser insertados en la base de datos.',
      'LBL_POTENTIALS_NOTE_1' => 'Oportunidad, Cuenta, Fecha de cierre, y estado de ventas son campos requeridos.',
      'LBL_OPPORTUNITIES_NOTE_1' => 'Oportunidad, Cuenta, Fecha de cierre, y estado de ventas son campos requeridos.',
      'LBL_LEADS_NOTE_1' => 'El Apellido debe Asignarse.',
      'LBL_LEADS_NOTE_2' => 'La Cuenta debe Asignarse.',
      'LBL_IMPORT_NOW' => 'Importar Ahora',
      'LBL_' => '',
      'LBL_CANNOT_OPEN' => 'No se puede abrir el archivo importado para su lectura',
      'LBL_NOT_SAME_NUMBER' => 'No habia la misma cantidad de campos por línea en el archivo',
      'LBL_NO_LINES' => 'No habia líneas en le archivo a importar',
      'LBL_FILE_ALREADY_BEEN_OR' => 'El archivo a importar ya fue procesado o no existe',
      'LBL_SUCCESS' => 'Importación Correcta:',
      'LBL_SUCCESSFULLY' => 'Importado satisfactoriamente',
      'LBL_LAST_IMPORT_UNDONE' => 'Su última importación fue deshecha',
      'LBL_NO_IMPORT_TO_UNDO' => 'No habia importación para deshacer.',
      'LBL_FAIL' => 'Importación Incorrecta:',
      'LBL_RECORDS_SKIPPED' => 'datos ignorados al no existir uno o más campos requeridos',
      'LBL_IDS_EXISTED_OR_LONGER' => 'datos ignorados al no existir id\'s o tener mas de 36 caracteres',
      'LBL_RESULTS' => 'Resultados',
      'LBL_IMPORT_MORE' => 'Importar Más',
      'LBL_FINISHED' => 'Finalizado',
      'LBL_UNDO_LAST_IMPORT' => 'Deshacer última importación',
      'LBL_SUCCESS_1' => 'Número de Elementos Importados/Actualizados Satisfactoriamente : ',
      'LBL_SKIPPED_1' => 'Número de Elementos Descartados ya que no tenían uno más campos requeridos : ',
      'LBL_PRODUCTS_NOTE_1' => 'El Nombre de Producto debe asignarse',
      'LBL_PRODUCTS_NOTE_2' => 'Antes de importar, compruebe que una columna no ha sido asignada dos veces',
      'LBL_FILE_LOCATION' => 'Localización del Fichero :',
      'LBL_STEP_2_3' => 'Paso 2 de 3 :',
      'LBL_LIST_MAPPING' => 'Listados y Asignaciones',
      'LBL_STEP_2_MSG' => 'Las siguientes tablas muestran los datos importados',
      'LBL_STEP_2_MSG1' => 'y otros detalles.',
      'LBL_STEP_2_TXT' => 'Para asignar los campos seleccione uno a uno el elemento correspondiente en los menús desplegables',
      'LBL_USE_SAVED_MAPPING' => 'Usar Asignación Guardada:',
      'LBL_MAPPING' => 'Asignado',
      'LBL_HEADERS' => 'Cabeceras :',
      'LBL_ERROR_MULTIPLE' => 'El mismo campo no puede ser asignado dos veces. Por favor compruebe los campos asignados.',
      'LBL_STEP_3_3' => 'Paso 3 de 3 : ',
      'LBL_MAPPING_RESULTS' => 'Resultados de Asignación',
      'LBL_LAST_IMPORTED' => 'Última Importación',
      'PLEASE_CHECK_MAPPING' => '\' está asignado más de una vez. Compruebe las asignaciones.',
      'MAP_MANDATORY_FIELD' => 'Asigne el campo requerido "',
      'ENTER_SAVEMAP_NAME' => 'Introduzca un nombre para la asignación',
      'to' => 'para',
      'of' => 'de',
      'are_imported_succesfully' => 'se han importado correctamente',

      // Added after 5.0.4 GA
        
      //added for duplicate handling 
      'LBL_LAST_IMPORT'=>'Ultimos Importados',
      'Select_Criteria_For_Duplicate' => 'Selecciona el Criterio de Manejo de Registros Duplicados',
      'Manual_Merging' => 'Combinación Manual',
      'Auto_Merging' => 'Combinación Automática',
      'Ignore_Duplicate' => 'Ignorar registros duplicados al importar',
      'Overwrite_Duplicate' => 'Sobreescribir los registros duplicados',
      'Duplicate_Records_Skipped_Info' => 'No. de Registros Saltados por duplicación : ',
      'Duplicate_Records_Overwrite_Info' => 'No. de Registros Sobreescritos por duplicación : ',
      'LBL_STEP_4_4' => 'Paso 4 de 4 : ',
      'LBL_STEP_3_4'=>'Paso 3 de 4 :',
      'LBL_STEP_2_4'=>'Paso 2 de 4 :',
      'LBL_STEP_1_4'=>'Paso 1 de 4 : ',

      'LBL_DELIMITER' => 'Separador:',
      'LBL_FORMAT' => 'Formato:',
      'LBL_MAX_FILE_SIZE' => ' es el tamaño máximo permitdo',

      'LBL_MERGE_FIELDS_DUPLICATE' => 'Campos de búsqueda para la detección de duplicados al importar.',
      'Customer Portal Login Details' => 'Detalles de Acceso al Portal del Cliente',
);
$mod_list_strings = array (
      'contacts_import_fields' => array(
            'firstname' => 'Nombre',
            'lastname' => 'Apellidos',
            'salutationtype' => 'Saludo',
            'leadsource' => 'Origen',
            'birthday' => 'Cumpleaños',
            'donotcall' => 'No Llamar',
            'emailoptout' => 'No Enviar Email',
            'account_id' => 'Cuenta',
            'title' => 'Cargo',
            'department' => 'Departamento',
            'homephone' => 'Tel. Particular',
            'mobile' => 'Tel. Móvil',
            'phone' => 'Tel. Oficina',
            'otherphone' => 'Tel. Adicional',
            'fax' => 'Fax',
            'email' => 'Email',
            'otheremail' => 'Email (Otro)',
            'secondaryemail' => 'Email Alternativo',
            'assistant' => 'Asistente',
            'assistantphone' => 'Teléfono de Secretaria',
            'mailingstreet' => 'Dirección (Envío)',
            'mailingpobox' => 'Apdo. Correos (Envío)',
            'mailingcity' => 'Población (Envío)',
            'mailingstate' => 'Provincia (Envío)',
            'mailingzip' => 'Código Postal (Envío)',
            'mailingcountry' => 'País (Envío)',
            'otherstreet' => 'Dirección (Alternativa)',
            'otherpobox' => 'Apdo. Correos (Alternativa)',
            'othercity' => 'Población (Alternativa)',
            'otherstate' => 'Provincia (Alternativa)',
            'otherzip' => 'Código postal (Alternativa)',
            'othercountry' => 'País (Alternativa)',
            'description' => 'Descripción',
            'assigned_user_id' => 'Asignado A',
                             ),
      'accounts_import_fields' => array(
            'accountname' => 'Nombre',
            'website' => 'Página Web',
            'industry' => 'Actividad',
            'accounttype' => 'Tipo',
            'tickersymbol' => 'Abreviatura de bolsa',
            'parent_name' => 'Miembro de',
            'employees' => 'Empleados',
            'ownership' => 'Accionistas',
            'phone' => 'Teléfono',
            'fax' => 'Fax',
            'otherphone' => 'Tel. Adicional',
            'email1' => 'Email',
            'email2' => 'Email Adicional',
            'rating' => 'Valoración',
            'siccode' => 'CIF',
            'annual_revenue' => 'Facturación Anual',
            'bill_street' => 'Dirección (Facturación)',
            'bill_pobox' => 'Apdo. Correos (Facturación)',
            'bill_city' => 'Población (Factura)',
            'bill_state' => 'Provincia (Factura)',
            'bill_code' => 'Código Postal (Factura)',
            'bill_country' => 'País (Factura)',
            'ship_street' => 'Dirección (Envío)',
            'ship_pobox' => 'Apdo. Correos (Envío)',
            'ship_city' => 'Población (Envío)',
            'ship_state' => 'Provincia (Envío)',
            'ship_code' => 'Código postal (Envío)',
            'ship_country' => 'País (Envío)',
            'description' => 'Descripción',
            'assigned_user_id' => 'Asignado a',
                             ),
      'potentials_import_fields' => array(
            'potentialname' => 'Oportunidad',
            'account_id' => 'Cuenta',
            'opportunity_type' => 'Tipo Oportunidad',
            'leadsource' => 'Origen',
            'amount' => 'Importe',
            'closingdate' => 'Fecha de Cierre',
            'nextstep' => 'Siguiente paso',
            'sales_stage' => 'Estado de Venta',
            'probability' => 'Probabilidad',
            'description' => 'Descripción',
            'assigned_user_id' => 'Asignado a',
                             ),
      'leads_import_fields' => array(
            'salutationtype' => '',
            'firstname' => 'Nombre',
            'phone' => 'Teléfono',
            'lastname' => 'Apellidos',
            'mobile' => 'Tel. Móvil',
            'company' => 'Cuenta',
            'fax' => 'Fax',
            'designation' => 'Designación',
            'email' => 'Email',
            'leadsource' => 'Origen',
            'website' => 'Página Web',
            'industry' => 'Actividad',
            'leadstatus' => 'Estado',
            'annualrevenue' => 'Facturación Anual',
            'rating' => 'Importancia',
            'noofemployees' => 'Nº de empleados',
            'assigned_user_id' => 'Asignado a',
            'secondaryemail' => 'Email Alternativo',
            'lane' => 'Dirección',
            'pobox' => 'Apdo. Correos',
            'code' => 'Código Postal',
            'city' => 'Población',
            'country' => 'País',
            'state' => 'Provincia',
            'description' => 'Descripción',
                             ),
      'products_import_fields' => array(
            'productname' => 'Nombre de Producto',
            'productcode' => 'Código de Producto',
            'productcategory' => 'Categoría de Producto',
            'manufacturer' => 'Fabricante',
            'product_description' => 'Descripción de Producto',
            'qty_per_unit' => 'Cantidad por unidad',
            'unit_price' => 'Precio Unitario',
            'weight' => 'Peso',
            'pack_size' => 'Tamaño del paquete',
            'start_date' => 'Fecha de Inicio',
            'expiry_date' => 'Fecha Vencimiento',
            'cost_factor' => 'Factor de Coste',
            'commissionmethod' => 'Método de Comisión',
            'discontinued' => 'Descatalogado',
            'commissionrate' => '% de Comisión',
            'sales_start_date' => 'Fecha de Salida al Mercado',
            'sales_end_date' => 'Fecha de Retirada del Mercado',
            'usageunit' => 'Unidad de Uso',
            'serialno' => 'Número de Serie',
            'currency' => 'moneda',
            'reorderlevel' => 'Stock mínimo',
            'website' => 'Página Web',
            'taxclass' => 'Tipo de Impuestos',
            'mfr_part_no' => 'Número de Parte de Fabricante',
            'vendor_part_no' => 'Número de Parte de Proveedor',
            'qtyinstock' => 'Cantidad en Stock',
            'productsheet' => 'Hoja de Producto',
            'qtyindemand' => 'Cantidad Pedida',
            'glacct' => 'Cuenta Contable',
            'assigned_user_id' => 'Asignado a',
                             ),
      'helpdesk_import_fields' => array(
            'ticketid' => 'Ticket Id',
            'priority' => 'Prioridad',
            'severity' => 'Urgencia',
            'status' => 'Status',
            'category' => 'Categoría',
            'title' => 'Cargo',
            'description' => 'Descripción',
            'solution' => 'Solución',
                             ),
      'vendors_import_fields' => array(
            'vendorid' => 'Id Proveedor',
            'vendorname' => 'Proveedor',
            'phone' => 'Teléfono',
            'email' => 'Email',
            'website' => 'Página Web',
            'category' => 'Categoría',
            'street' => 'Dirección',
            'city' => 'Población',
            'state' => 'Provincia',
            'pobox' => 'Apdo. Correos',
            'postalcode' => 'Cód. Postal',
            'country' => 'Country',
            'description' => 'Descripción',
                             ),
);
?>
